#!/usr/bin/env python3
#
# Copyright 2019 PSB
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ec_model_data_standard_exchange_scenario.py

Shut down reactions according to CellNetAnalyzer's ECGS model scenario :D
Acetate and succinate exchanges are not set as shut down since their secretion really
occurs biologically in the course of the Crabtree effect :D
"""

ec_model_shut_down_reactions = [
 # "EX_ac_e",
 "DM_aacald_c",
 "DM_aacald_c",
 "DM_oxam_c",
 "BIOMASS_Ec_iJO1366_WT_53p95M",
 "EX_12ppd__R_e",
 "EX_12ppd__S_e",
 "EX_14glucan_e",
 "EX_15dap_e",
 "EX_23camp_e",
 "EX_23ccmp_e",
 "EX_23cgmp_e",
 "EX_23cump_e",
 "EX_23dappa_e",
 "EX_26dap__M_e",
 "EX_2ddglcn_e",
 "EX_34dhpac_e",
 "EX_3amp_e",
 "EX_3cmp_e",
 "EX_3gmp_e",
 "EX_3hcinnm_e",
 "EX_3hpp_e",
 "EX_3hpppn_e",
 "EX_3ump_e",
 "EX_4abut_e",
 "EX_4hoxpacd_e",
 "EX_5dglcn_e",
 "EX_5mtr_e",
 "EX_LalaDglu_e",
 "EX_LalaDgluMdap_e",
 "EX_LalaDgluMdapDala_e",
 "EX_LalaLglu_e",
 "EX_acac_e",
 "EX_acald_e",
 "EX_acgal_e",
 "EX_acgal1p_e",
 "EX_acgam_e",
 "EX_acgam1p_e",
 "EX_acmana_e",
 "EX_acmum_e",
 "EX_acnam_e",
 "EX_acolipa_e",
 "EX_acser_e",
 "EX_ade_e",
 "EX_adn_e",
 "EX_adocbl_e",
 "EX_ag_e",
 "EX_agm_e",
 "EX_akg_e",
 "EX_ala_B_e",
 "EX_ala__D_e",
 "EX_ala__L_e",
 "EX_alaala_e",
 "EX_all__D_e",
 "EX_alltn_e",
 "EX_amp_e",
 "EX_anhgm_e",
 "EX_arab__L_e",
 "EX_arbt_e",
 "EX_arbtn_e",
 "EX_arbtn_fe3_e",
 "EX_arg__L_e",
 "EX_ascb__L_e",
 "EX_asn__L_e",
 "EX_aso3_e",
 "EX_asp__L_e",
 "EX_btn_e",
 "EX_but_e",
 "EX_butso3_e",
 "EX_cbi_e",
 "EX_cd2_e",
 "EX_cgly_e",
 "EX_chol_e",
 "EX_chtbs_e",
 "EX_cit_e",
 "EX_cm_e",
 "EX_cmp_e",
 "EX_colipa_e",
 "EX_colipap_e",
 "EX_cpgn_e",
 "EX_cpgn_un_e",
 "EX_crn_e",
 "EX_crn__D_e",
 "EX_csn_e",
 "EX_cu_e",
 "EX_cyan_e",
 "EX_cynt_e",
 "EX_cys__D_e",
 "EX_cys__L_e",
 "EX_cytd_e",
 "EX_dad_2_e",
 "EX_damp_e",
 "EX_dca_e",
 "EX_dcmp_e",
 "EX_dcyt_e",
 "EX_ddca_e",
 "EX_dgmp_e",
 "EX_dgsn_e",
 "EX_dha_e",
 "EX_dimp_e",
 "EX_din_e",
 "EX_dms_e",
 "EX_dmso_e",
 "EX_dopa_e",
 "EX_doxrbcn_e",
 "EX_dtmp_e",
 "EX_dump_e",
 "EX_duri_e",
 "EX_eca4colipa_e",
 "EX_enlipa_e",
 "EX_enter_e",
 "EX_etha_e",
 "EX_ethso3_e",
 "EX_f6p_e",
 "EX_fald_e",
 "EX_fe3dcit_e",
 "EX_fe3dhbzs_e",
 "EX_fe3hox_e",
 "EX_fe3hox_un_e",
 "EX_fecrm_e",
 "EX_fecrm_un_e",
 "EX_feenter_e",
 "EX_feoxam_e",
 "EX_feoxam_un_e",
 "EX_fru_e",
 "EX_frulys_e",
 "EX_fruur_e",
 "EX_fuc__L_e",
 "EX_fum_e",
 "EX_fusa_e",
 "EX_g1p_e",
 "EX_g3pc_e",
 "EX_g3pe_e",
 "EX_g3pg_e",
 "EX_g3pi_e",
 "EX_g3ps_e",
 "EX_g6p_e",
 "EX_gal_e",
 "EX_gal_bD_e",
 "EX_gal1p_e",
 "EX_galct__D_e",
 "EX_galctn__D_e",
 "EX_galctn__L_e",
 "EX_galt_e",
 "EX_galur_e",
 "EX_gam_e",
 "EX_gam6p_e",
 "EX_gbbtn_e",
 "EX_gdp_e",
 "EX_glcn_e",
 "EX_glcr_e",
 "EX_glcur_e",
 "EX_glcur1p_e",
 "EX_gln__L_e",
 "EX_glu__L_e",
 "EX_gly_e",
 "EX_glyald_e",
 "EX_glyb_e",
 "EX_glyc_e",
 "EX_glyc__R_e",
 "EX_glyc2p_e",
 "EX_glyc3p_e",
 "EX_glyclt_e",
 "EX_gmp_e",
 "EX_gsn_e",
 "EX_gthox_e",
 "EX_gthrd_e",
 "EX_gtp_e",
 "EX_gua_e",
 "EX_h2o2_e",
 "EX_h2s_e",
 "EX_hacolipa_e",
 "EX_halipa_e",
 "EX_hdca_e",
 "EX_hdcea_e",
 "EX_hg2_e",
 "EX_his__L_e",
 "EX_hom__L_e",
 "EX_hxa_e",
 "EX_hxan_e",
 "EX_idon__L_e",
 "EX_ile__L_e",
 "EX_imp_e",
 "EX_indole_e",
 "EX_inost_e",
 "EX_ins_e",
 "EX_isetac_e",
 "EX_kdo2lipid4_e",
 "EX_lac__L_e",
 "EX_lcts_e",
 "EX_leu__L_e",
 "EX_lipa_e",
 "EX_lipa_cold_e",
 "EX_lipoate_e",
 "EX_lys__L_e",
 "EX_lyx__L_e",
 "EX_mal__D_e",
 "EX_mal__L_e",
 "EX_malt_e",
 "EX_malthx_e",
 "EX_maltpt_e",
 "EX_malttr_e",
 "EX_maltttr_e",
 "EX_man_e",
 "EX_man6p_e",
 "EX_manglyc_e",
 "EX_melib_e",
 "EX_met__D_e",
 "EX_met__L_e",
 "EX_metsox_R__L_e",
 "EX_metsox_S__L_e",
 "EX_mincyc_e",
 "EX_minohp_e",
 "EX_mmet_e",
 "EX_mnl_e",
 "EX_mso3_e",
 "EX_n2o_e",
 "EX_na1_e",
 "EX_nac_e",
 "EX_nmn_e",
 "EX_no_e",
 "EX_no2_e",
 "EX_no3_e",
 "EX_novbcn_e",
 "EX_o16a4colipa_e",
 "EX_o2s_e",
 "EX_ocdca_e",
 "EX_ocdcea_e",
 "EX_octa_e",
 "EX_orn_e",
 "EX_orot_e",
 "EX_pacald_e",
 "EX_peamn_e",
 "EX_phe__L_e",
 "EX_pheme_e",
 "EX_pnto__R_e",
 "EX_ppa_e",
 "EX_ppal_e",
 "EX_pppn_e",
 "EX_ppt_e",
 "EX_pro__L_e",
 "EX_progly_e",
 "EX_psclys_e",
 "EX_pser__L_e",
 "EX_ptrc_e",
 "EX_pydam_e",
 "EX_pydx_e",
 "EX_pydxn_e",
 "EX_pyr_e",
 "EX_quin_e",
 "EX_r5p_e",
 "EX_rfamp_e",
 "EX_rib__D_e",
 "EX_rmn_e",
 "EX_sbt__D_e",
 "EX_sel_e",
 "EX_ser__D_e",
 "EX_ser__L_e",
 "EX_skm_e",
 "EX_slnt_e",
 "EX_so2_e",
 "EX_so3_e",
 "EX_spmd_e",
 # "EX_succ_e",
 "EX_sucr_e",
 "EX_sulfac_e",
 "EX_tartr__D_e",
 "EX_tartr__L_e",
 "EX_taur_e",
 "EX_tcynt_e",
 "EX_thm_e",
 "EX_thr__L_e",
 "EX_thrp_e",
 "EX_thym_e",
 "EX_thymd_e",
 "EX_tma_e",
 "EX_tmao_e",
 "EX_tre_e",
 "EX_trp__L_e",
 "EX_tsul_e",
 "EX_ttdca_e",
 "EX_ttdcea_e",
 "EX_ttrcyc_e",
 "EX_tungs_e",
 "EX_tym_e",
 "EX_tyr__L_e",
 "EX_tyrp_e",
 "EX_uacgam_e",
 "EX_udpacgal_e",
 "EX_udpg_e",
 "EX_udpgal_e",
 "EX_udpglcur_e",
 "EX_ump_e",
 "EX_ura_e",
 "EX_urea_e",
 "EX_uri_e",
 "EX_val__L_e",
 "EX_xan_e",
 "EX_xmp_e",
 "EX_xtsn_e",
 "EX_xyl__D_e",
 "EX_xylu__L_e",
]
